AGW Logo

svn SVN Revision 70845 For customtreectrl

This file contains the SVN revision history for customtreectrl, at revision 70845.

Available information include commit date, the name of the committer, the file size, the SVN log messages and a diff from the previous version (if available).


file_info File Information

  • Commit Date: 17-Oct-2008 20:51:43 UTC
  • Committer: AG
  • File Size: 297001 byte(s)

svn_log Log Messages

The following log message was entered by the committer:

CustomTreeCtrl: fix wrong scrolling behaviour of windows when using the style TR_ALIGN_WINDOWS.


svn_diff Diff To Previous Version (70830)

Version SVN diff:

--- wxPython/3rdParty/AGW/agw/customtreectrl.py     2012/03/06 21:10:55     70830
+++ wxPython/3rdParty/AGW/agw/customtreectrl.py     2012/03/08 19:16:09     70845
@@ -3,7 +3,7 @@
# Inspired By And Heavily Based On wxGenericTreeCtrl.
#
# Andrea Gavana, @ 17 May 2006
# Latest Revision: 06 Mar 2012, 21.00 GMT
#
#
# TODO List
@@ -299,7 +299,7 @@

L{CustomTreeCtrl} is distributed under the wxPython license.

-Latest Revision: Andrea Gavana @ 06 Mar 2012, 21.00 GMT
+Latest Revision: Andrea Gavana @ 08 Mar 2012, 21.00 GMT

Version 2.6

@@ -6672,11 +6672,11 @@
if align == 1:
# Horizontal alignment of windows
if level in self.absoluteWindows:
-                    wndx = self.absoluteWindows[level] + item.GetX() + 2
+                    wndx = self.absoluteWindows[level] + item.GetX() + 2 + xa

elif align == 2:
# Rightmost alignment of windows
-                wndx = w - item.GetWindowSize().x - 2
+                wndx = w - item.GetWindowSize().x - 2 + xa

if not wnd.IsShown():
wnd.Show()
@@ -3,7 +3,7 @@
#
# Andrea Gavana, @ 17 May 2006
-# Latest Revision: 06 Mar 2012, 21.00 GMT
+# Latest Revision: 08 Mar 2012, 21.00 GMT
#
#
Tree